Package: spc
Version: 0.7.2
Date: 2025-09-25
Title: Statistical Process Control -- Calculation of ARL and Other
        Control Chart Performance Measures
Authors@R: person(given = "Sven",
                    family = "Knoth",
                    role = c("aut", "cre"),
                    email = "Sven.Knoth@gmx.de")
Depends: R (>= 1.8.0)
Description: Evaluation of control charts by means of
        the zero-state, steady-state ARL (Average Run Length) and RL quantiles.
        Setting up control charts for given in-control ARL. The control charts
        under consideration are one- and two-sided EWMA, CUSUM, and
        Shiryaev-Roberts schemes for monitoring the mean or variance of normally
        distributed independent data. ARL calculation of the same set of schemes under drift (in the mean) are added.
        Eventually, all ARL measures for the multivariate EWMA (MEWMA) are provided.
License: GPL (>= 2)
URL: https://www.r-project.org
NeedsCompilation: yes
Packaged: 2025-09-23 19:56:28 UTC; knoth
Author: Sven Knoth [aut, cre]
Maintainer: Sven Knoth <Sven.Knoth@gmx.de>
Repository: CRAN
Date/Publication: 2025-09-24 05:10:09 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-26 14:03:02 UTC; unix
Archs: spc.so.dSYM
