useDynLib(spc, .registration=TRUE)
## imports
import("stats")
## exports
export("xshewhartrunsrules.ad", "xshewhartrunsrules.arl", "xshewhartrunsrules.crit", "xshewhartrunsrules.matrix",
       "xshewhart.ar1.arl", "xtshewhart.ar1.arl",
       "xewma.ad", "xewma.arl", "xewma.arl.f", "xewma.crit", "xewma.q", "xewma.sf", "xewma.q.crit",
       "xcusum.ad", "xcusum.arl", "xcusum.crit.L0h", "xcusum.crit.L0L1", "xcusum.crit", "xcusum.q", "xcusum.sf",
       "xgrsr.ad", "xgrsr.arl", "xgrsr.crit",
       "sewma.arl", "sewma.crit", "sewma.sf", "sewma.q.crit", "sewma.q",
       "sewma.sf.prerun", "sewma.arl.prerun", "sewma.q.crit.prerun", "sewma.q.prerun", "sewma.crit.prerun",
       "lns2ewma.arl", "lns2ewma.crit",
       "scusum.arl", "scusum.crit", "scusums.arl",
       "mewma.arl", "mewma.crit", "mewma.psi", "mewma.arl.f", "mewma.ad",
       "xsewma.arl", "xsewma.crit", "xsewma.sf", "xsewma.q.crit", "xsewma.q",
       "xewma.arl.prerun", "xewma.q.prerun", "xewma.sf.prerun",
       "xewma.crit.prerun", "xewma.q.crit.prerun",
       "xtewma.arl", "xtewma.ad", "xtewma.sf", "xtewma.q", "xtewma.q.crit",
       "xtcusum.arl",
       "xDcusum.arl", "xDewma.arl", "xDgrsr.arl", "xDshewhartrunsrules.arl", "xDshewhartrunsrulesFixedm.arl",
       "p.ewma.arl", "tewma.arl", "euklid.ewma.arl",
       "pois.ewma.arl", "pois.ewma.crit", "pois.ewma.ad",
       "pois.cusum.arl", "pois.cusum.crit", "pois.cusum.crit.L0L1",
       "imr.arl", "imr.Ru_Mgiven", "imr.Ru_Mgiven", "imr.Rl_Mgiven", "imr.MandRu",
       "imr.MandRuRl", "imr.RuRl_alone_tail", "imr.RuRl_alone_s3", "imr.RuRl_alone", "imr.Ru_Rlgiven", "imr.Rl_Rugiven",
       "phat.ewma.arl", "phat.ewma.crit", "phat.ewma.lambda", "dphat", "pphat", "qphat",
       "s.res.ewma.arl", "x.res.ewma.arl", "xs.res.ewma.arl", "xs.res.ewma.pms",
       "quadrature.nodes.weights",   
       "tol.lim.fac")
